@@ -13,10 +13,10 @@ async fn index(
     jar: &CookieJar<'_>,
     config: &State<PrintNannyConfig>,
 ) -> Result<Response, FlashResponse<Template>> {
-    let api_config = jar.get_private(auth::COOKIE_API_CONFIG);
+    let api_config = jar.get_private(auth::COOKIE_CONFIG);
     match api_config {
         Some(cookie) => {
-            let api_config = serde_json::from_str(cookie.value())?;
+            let config = serde_json::from_str(cookie.value())?;
             let context = auth::get_context(config).await?;
             info!("Attaching context to view {:?}", context);
             Ok(Response::Template(Template::render("index", context)))
